markuptools.make_big_centered_page_number_markup
================================================

.. autofunction:: abjad.tools.markuptools.make_big_centered_page_number_markup.make_big_centered_page_number_markup
